| Title: | Complete Text of the LDS Scriptures |
|---|---|
| Description: | Full text, in data frames containing one row per verse, of the Standard Works of The Church of Jesus Christ of Latter-day Saints (LDS). These are the Old Testament, (KJV), the New Testament (KJV), the Book of Mormon, the Doctrine and Covenants, and the Pearl of Great Price. |
| Authors: | Andrew Heiss [aut, cre] |
| Maintainer: | Andrew Heiss <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-27 10:41:58 UTC |
| Source: | https://github.com/andrewheiss/scripturs |
A dataset containing the text of the Book of Mormon.
book_of_mormonbook_of_mormon
A data frame with 6604 rows and 19 columns:
volume_idUnique id number for the volume
book_idUnique id number for the book
chapter_idUnique id number for the chapter
verse_idUnique id number for the verse
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter
verse_numberVerse
textScripture text
verse_titleCombined book, chapter, and verse (e.g. 1 Nephi 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. 1 Ne. 1:1)
Excludes the following:
Book of Mormon: Title Page (written by Moroni)
Introduction
The Testimony of the Three Witnesses
The Testimony of Eight Witnesses
Testimony of the Prophet Joseph Smith
A Brief Explanation About the Book of Mormon
A dataset containing the text of the Doctrine and Covenants.
doctrine_and_covenantsdoctrine_and_covenants
A data frame with 3654 rows and 19 columns:
volume_idUnique id number for the volume
book_idUnique id number for the book
chapter_idUnique id number for the chapter
verse_idUnique id number for the verse
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter
verse_numberVerse
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Doctrine and Covenants 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. D&C 1:1)
Excludes the following:
Official Declaration 1
Official Declaration 2
Returns a tidy data frame of the King James Version of the Bible, with one
verse for every row. There are several columns, including: text, which
contains the text of each verse, book_title, the book of scripture,
chapter_number, the chapter, and verse_number, the verse
number. There are a dozen other columns as well: see "Details" for complete
descriptions.
kjv_bible()kjv_bible()
Importantly, none of the title columns are ordered factors. It is the responsibility of the user to create ordered factors of book and volume titles when plotting results.
Every row in the dataset is a verse, and there are 19 columns of metadata:
volume_idUnique id number for the volume (1 = Old Testament, 2 = New Testament, etc.)
book_idUnique id number for the book (1 = Genesis, 2 = Exodus, etc.)
chapter_idUnique id number for the chapter (50 = Genesis 50, 51 = Exodus 1, etc.)
verse_idUnique id number for the verse (31 = Genesis 1:31, 32 = Genesis 2:1)
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter (not unique; Genesis 50 = 50, Exodus 1 = 1, etc.)
verse_numberVerse (not unique; Genesis 1:31 = 31, Genesis 2:1 = 1)
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Genesis 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. Gen. 1:1)
A data frame with 31102 rows and 19 columns
library(dplyr) kjv_bible() %>% group_by(volume_title, book_title) %>% summarise(total_verses = n())library(dplyr) kjv_bible() %>% group_by(volume_title, book_title) %>% summarise(total_verses = n())
Returns a tidy data frame of the Standard Works of The Church of Jesus Christ
of Latter-day Saints (LDS) (King James Bible, Book of Mormon, Doctrine and
Covenants, and the Pearl of Great Price), with one verse for every row. There
are several columns, including: text, which contains the text of each
verse, book_title, the book of scripture, chapter_number, the
chapter, and verse_number, the verse number. There are a dozen other
columns as well: see "Details" for complete descriptions.
lds_scriptures()lds_scriptures()
Importantly, none of the title columns are ordered factors. It is the responsibility of the user to create ordered factors of book and volume titles when plotting results.
Every row in the dataset is a verse, and there are 19 columns of metadata:
volume_idUnique id number for the volume (1 = Old Testament, 2 = New Testament, etc.)
book_idUnique id number for the book (1 = Genesis, 2 = Exodus, etc.)
chapter_idUnique id number for the chapter (50 = Genesis 50, 51 = Exodus 1, etc.)
verse_idUnique id number for the verse (31 = Genesis 1:31, 32 = Genesis 2:1)
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter (not unique; Genesis 50 = 50, Exodus 1 = 1, etc.)
verse_numberVerse (not unique; Genesis 1:31 = 31, Genesis 2:1 = 1)
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Genesis 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. Gen. 1:1)
A data frame with 41995 rows and 19 columns
library(dplyr) lds_scriptures() %>% group_by(volume_title, book_title) %>% summarise(total_verses = n())library(dplyr) lds_scriptures() %>% group_by(volume_title, book_title) %>% summarise(total_verses = n())
A dataset containing the text of the King James Version of the New Testament.
new_testamentnew_testament
A data frame with 7957 rows and 19 columns:
volume_idUnique id number for the volume
book_idUnique id number for the book
chapter_idUnique id number for the chapter
verse_idUnique id number for the verse
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter
verse_numberVerse
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Matthew 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. Matt. 1:1)
A dataset containing the text of the King James Version of the Old Testament.
old_testamentold_testament
A data frame with 23145 rows and 19 columns:
volume_idUnique id number for the volume
book_idUnique id number for the book
chapter_idUnique id number for the chapter
verse_idUnique id number for the verse
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter
verse_numberVerse
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Genesis 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. Gen. 1:1)
Excludes the following:
Epistle Dedicatory
A dataset containing the text of the Pearl of Great Price.
pearl_of_great_pricepearl_of_great_price
A data frame with 635 rows and 19 columns:
volume_idUnique id number for the volume
book_idUnique id number for the book
chapter_idUnique id number for the chapter
verse_idUnique id number for the verse
volume_titleName of the volume
book_titleName of the book
volume_long_titleFull name of the volume
book_long_titleFull name of the book
volume_subtitleSubtitle of the volume
book_subtitleSubtitle of the book
volume_short_titleVolume abbreviation
book_short_titleBook abbreviation
volume_lds_urlVolume abbreviation used at scriptures.lds.org
book_lds_urlBook abbreviation used at scriptures.lds.org
chapter_numberChapter
verse_numberVerse
textScripture text
verse_titleCombined book, chapter, and verse (e.g. Abraham 1:1)
verse_short_titleAbbreviated combined book, chapter, and verse (e.g. Abr. 1:1)
Excludes the following:
Introductory Note
Oliver Cowdery's account
This package contains the complete text of the Standard Works of The Church of Jesus Christ of Latter-day Saints (LDS), including the King James Bible (Old and New Testaments), the Book of Mormon, the Doctrine and Covenants, and the Pearl of Great Price, formatted to be convenient for text analysis.